@@ -1,9 +1,22 @@
-"""The command line interface implementation for PyPRQL."""
+"""The command line interface implementation for pyprql."""
 import sys
+import warnings
 from typing import List, Optional
 
 from pyprql.cli.cli import CLI
 
+warnings.warn(
+    """
+Currently the pyprql CLI is unfortunately deprecated, since the original creators are no
+longer active. It was a valiant effort, and of the first things that was built on top of
+PRQL. But it's a big project that requires work to keep it current.
+
+If anyone would be interested in taking it over, please feel free to start contributing,
+and we can un-deprecate it.
+""",
+    DeprecationWarning,
+)
+
 
 def main(params: Optional[List[str]] = None) -> None:
     """Serve the CLI entrypoint.
